@@ -18,6 +18,15 @@ class Test(TestCase):
         assert vector3_decoded.x == 1
         assert vector3_decoded == vector3
 
+    def test_vector3_equals(self):
+        v1 = Vector3(1, 2, 3)
+        v2 = Vector3(1, 2, 3)
+        v3 = Vector3(3000, 2, 3)
+
+        assert v1 == v2
+        assert v1 != v3
+        assert v1 != "hej"
+
     def test_pose(self):
         name = "waypoint_1"
         position = Vector3(1, 2, 3)
@@ -37,6 +46,15 @@ class Test(TestCase):
         assert pose_decoded.orientation == orientation
         assert pose_decoded == pose
 
+    def test_pose_equals(self):
+        pose1 = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3))
+        pose2 = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3))
+        pose3 = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3), "some name")
+
+        assert pose1 == pose2
+        assert pose1 != pose3
+        assert pose1 != "hej"
+
     def test_poses(self):
         list_of_poses = [
             Pose(Vector3(1, 1, 1), Vector3(-1.1, -1.2, 1.3), "waypoint_1"),
@@ -57,3 +75,23 @@ class Test(TestCase):
         assert poses_decoded.poses == list_of_poses
         assert poses_decoded == poses, "The decoded object must be equal to the encoded"
 
+    def test_poses_equals(self):
+        list_of_poses = [
+            Pose(Vector3(1, 1, 1), Vector3(-1.1, -1.2, 1.3), "waypoint_1"),
+            Pose(Vector3(2, 2, 2), Vector3(-1.2, -1.1, 1.3), "waypoint_2"),
+        ]
+        poses1 = Poses(list_of_poses)
+        poses2 = Poses(list_of_poses)
+        poses3 = Poses(list_of_poses, connected=True)
+
+        assert poses1 == poses2
+        assert poses1 != poses3
+        assert poses1 != list_of_poses
+
+    def test_poses_add(self):
+        pose = Pose(Vector3(1, 1, 1), Vector3(-1.1, -1.2, 1.3), "waypoint_1")
+        poses = Poses([])
+        poses.add(pose)
+
+        assert len(poses.poses) == 1
+        assert pose in poses.poses
