@@ -17,3 +17,12 @@ class Test(TestCase):
         status_decoded = json_decode(status_string)
         assert type(status_decoded) == Status, f"Got: {type(status_decoded)}. Expected {Status}"
         assert status_decoded == status, "The decoded object must be equal to the encoded"
+
+    def test_status_equals(self):
+        s1 = Status('data_objects', '127.0.0.1', Status.OFFLINE)
+        s2 = Status('data_objects', '127.0.0.1', Status.OFFLINE)
+        s3 = Status('data_objects', '127.0.0.1', Status.ONLINE)
+
+        assert s1 == s2
+        assert s1 != s3
+        assert s1 != "not status"
